@@ -1,16 +1,17 @@
-# -*- coding: utf-8 -*-
-
 """Collection of tests around cookiecutter's command-line interface."""
 
 import json
 import os
-import sys
+import re
+
 
 import pytest
 from click.testing import CliRunner
 
 from cookiecutter import utils
 from cookiecutter.__main__ import main
+from cookiecutter.environment import StrictEnvironment
+from cookiecutter.exceptions import UnknownExtension
 from cookiecutter.main import cookiecutter
 
 
@@ -19,9 +20,9 @@ def cli_runner():
     """Fixture that returns a helper function to run the cookiecutter cli."""
     runner = CliRunner()
 
-    def cli_main(*cli_args):
+    def cli_main(*cli_args, **cli_kwargs):
         """Run cookiecutter cli main with the given args."""
-        return runner.invoke(main, cli_args)
+        return runner.invoke(main, cli_args, **cli_kwargs)
 
     return cli_main
 
@@ -50,7 +51,7 @@ def version_cli_flag(request):
 
 
 def test_cli_version(cli_runner, version_cli_flag):
-    """Verify correct version output by `cookiecutter` on cli invocation."""
+    """Verify Cookiecutter version output by `cookiecutter` on cli invocation."""
     result = cli_runner(version_cli_flag)
     assert result.exit_code == 0
     assert result.output.startswith('Cookiecutter')
@@ -107,6 +108,33 @@ def test_cli_replay(mocker, cli_runner):
         extra_context=None,
         password=None,
         directory=None,
+        accept_hooks=True,
+    )
+
+
+@pytest.mark.usefixtures('remove_fake_project_dir')
+def test_cli_replay_file(mocker, cli_runner):
+    """Test cli invocation correctly pass --replay-file option."""
+    mock_cookiecutter = mocker.patch('cookiecutter.cli.cookiecutter')
+
+    template_path = 'tests/fake-repo-pre/'
+    result = cli_runner(template_path, '--replay-file', '~/custom-replay-file', '-v')
+
+    assert result.exit_code == 0
+    mock_cookiecutter.assert_called_once_with(
+        template_path,
+        None,
+        False,
+        replay='~/custom-replay-file',
+        overwrite_if_exists=False,
+        skip_if_file_exists=False,
+        output_dir='.',
+        config_file=None,
+        default_config=False,
+        extra_context=None,
+        password=None,
+        directory=None,
+        accept_hooks=True,
     )
 
 
@@ -123,7 +151,7 @@ def test_cli_exit_on_noinput_and_replay(mocker, cli_runner):
     assert result.exit_code == 1
 
     expected_error_msg = (
-        "You can not use both replay and no_input or extra_context " "at the same time."
+        "You can not use both replay and no_input or extra_context at the same time."
     )
 
     assert expected_error_msg in result.output
@@ -141,6 +169,7 @@ def test_cli_exit_on_noinput_and_replay(mocker, cli_runner):
         extra_context=None,
         password=None,
         directory=None,
+        accept_hooks=True,
     )
 
 
@@ -155,9 +184,7 @@ def test_run_cookiecutter_on_overwrite_if_exists_and_replay(
     mocker, cli_runner, overwrite_cli_flag
 ):
     """Test cli invocation with `overwrite-if-exists` and `replay` flags."""
-    mock_cookiecutter = mocker.patch(
-        'cookiecutter.cli.cookiecutter', side_effect=cookiecutter
-    )
+    mock_cookiecutter = mocker.patch('cookiecutter.cli.cookiecutter')
 
     template_path = 'tests/fake-repo-pre/'
     result = cli_runner(template_path, '--replay', '-v', overwrite_cli_flag)
@@ -177,6 +204,7 @@ def test_run_cookiecutter_on_overwrite_if_exists_and_replay(
         extra_context=None,
         password=None,
         directory=None,
+        accept_hooks=True,
     )
 
 
@@ -211,12 +239,6 @@ def output_dir_flag(request):
     return request.param
 
 
-@pytest.fixture
-def output_dir(tmpdir):
-    """Pytest fixture return `output_dir` argument as string."""
-    return str(tmpdir.mkdir('output'))
-
-
 def test_cli_output_dir(mocker, cli_runner, output_dir_flag, output_dir):
     """Test cli invocation with `output-dir` flag changes output directory."""
     mock_cookiecutter = mocker.patch('cookiecutter.cli.cookiecutter')
@@ -238,6 +260,7 @@ def test_cli_output_dir(mocker, cli_runner, output_dir_flag, output_dir):
         extra_context=None,
         password=None,
         directory=None,
+        accept_hooks=True,
     )
 
 
@@ -255,9 +278,9 @@ def test_cli_help(cli_runner, help_cli_flag):
 
 
 @pytest.fixture
-def user_config_path(tmpdir):
+def user_config_path(tmp_path):
     """Pytest fixture return `user_config` argument as string."""
-    return str(tmpdir.join('tests/config.yaml'))
+    return str(tmp_path.joinpath("tests", "config.yaml"))
 
 
 def test_user_config(mocker, cli_runner, user_config_path):
@@ -281,6 +304,7 @@ def test_user_config(mocker, cli_runner, user_config_path):
         extra_context=None,
         password=None,
         directory=None,
+        accept_hooks=True,
     )
 
 
@@ -290,7 +314,10 @@ def test_default_user_config_overwrite(mocker, cli_runner, user_config_path):
 
     template_path = 'tests/fake-repo-pre/'
     result = cli_runner(
-        template_path, '--config-file', user_config_path, '--default-config',
+        template_path,
+        '--config-file',
+        user_config_path,
+        '--default-config',
     )
 
     assert result.exit_code == 0
@@ -307,6 +334,7 @@ def test_default_user_config_overwrite(mocker, cli_runner, user_config_path):
         extra_context=None,
         password=None,
         directory=None,
+        accept_hooks=True,
     )
 
 
@@ -331,20 +359,20 @@ def test_default_user_config(mocker, cli_runner):
         extra_context=None,
         password=None,
         directory=None,
+        accept_hooks=True,
     )
 
 
-@pytest.mark.skipif(
-    sys.version_info[0] == 3 and sys.version_info[1] == 6 and sys.version_info[2] == 1,
-    reason="Outdated pypy3 version on Travis CI/CD with wrong OrderedDict syntax.",
-)
-def test_echo_undefined_variable_error(tmpdir, cli_runner):
+def test_echo_undefined_variable_error(output_dir, cli_runner):
     """Cli invocation return error if variable undefined in template."""
-    output_dir = str(tmpdir.mkdir('output'))
     template_path = 'tests/undefined-variable/file-name/'
 
     result = cli_runner(
-        '--no-input', '--default-config', '--output-dir', output_dir, template_path,
+        '--no-input',
+        '--default-config',
+        '--output-dir',
+        output_dir,
+        template_path,
     )
 
     assert result.exit_code == 1
@@ -362,19 +390,23 @@ def test_echo_undefined_variable_error(tmpdir, cli_runner):
             'github_username': 'hackebrot',
             'project_slug': 'testproject',
             '_template': template_path,
+            '_output_dir': output_dir,
         }
     }
     context_str = json.dumps(context, indent=4, sort_keys=True)
     assert context_str in result.output
 
 
-def test_echo_unknown_extension_error(tmpdir, cli_runner):
+def test_echo_unknown_extension_error(output_dir, cli_runner):
     """Cli return error if extension incorrectly defined in template."""
-    output_dir = str(tmpdir.mkdir('output'))
     template_path = 'tests/test-extensions/unknown/'
 
     result = cli_runner(
-        '--no-input', '--default-config', '--output-dir', output_dir, template_path,
+        '--no-input',
+        '--default-config',
+        '--output-dir',
+        output_dir,
+        template_path,
     )
 
     assert result.exit_code == 1
@@ -382,11 +414,43 @@ def test_echo_unknown_extension_error(tmpdir, cli_runner):
     assert 'Unable to load extension: ' in result.output
 
 
+def test_local_extension(tmpdir, cli_runner):
+    """Test to verify correct work of extension, included in template."""
+    output_dir = str(tmpdir.mkdir('output'))
+    template_path = 'tests/test-extensions/local_extension/'
+
+    result = cli_runner(
+        '--no-input',
+        '--default-config',
+        '--output-dir',
+        output_dir,
+        template_path,
+    )
+    assert result.exit_code == 0
+    with open(os.path.join(output_dir, 'Foobar', 'HISTORY.rst')) as f:
+        data = f.read()
+        assert 'FoobarFoobar' in data
+        assert 'FOOBAR' in data
+
+
+def test_local_extension_not_available(tmpdir, cli_runner):
+    """Test handling of included but unavailable local extension."""
+    context = {'cookiecutter': {'_extensions': ['foobar']}}
+
+    with pytest.raises(UnknownExtension) as err:
+        StrictEnvironment(context=context, keep_trailing_newline=True)
+
+    assert 'Unable to load extension: ' in str(err.value)
+
+
 @pytest.mark.usefixtures('remove_fake_project_dir')
 def test_cli_extra_context(cli_runner):
     """Cli invocation replace content if called with replacement pairs."""
     result = cli_runner(
-        'tests/fake-repo-pre/', '--no-input', '-v', 'project_name=Awesomez',
+        'tests/fake-repo-pre/',
+        '--no-input',
+        '-v',
+        'project_name=Awesomez',
     )
     assert result.exit_code == 0
     assert os.path.isdir('fake-project')
@@ -398,7 +462,10 @@ def test_cli_extra_context(cli_runner):
 def test_cli_extra_context_invalid_format(cli_runner):
     """Cli invocation raise error if called with unknown argument."""
     result = cli_runner(
-        'tests/fake-repo-pre/', '--no-input', '-v', 'ExtraContextWithNoEqualsSoInvalid',
+        'tests/fake-repo-pre/',
+        '--no-input',
+        '-v',
+        'ExtraContextWithNoEqualsSoInvalid',
     )
     assert result.exit_code == 2
     assert "Error: Invalid value for '[EXTRA_CONTEXT]...'" in result.output
@@ -406,9 +473,9 @@ def test_cli_extra_context_invalid_format(cli_runner):
 
 
 @pytest.fixture
-def debug_file(tmpdir):
+def debug_file(tmp_path):
     """Pytest fixture return `debug_file` argument as path object."""
-    return tmpdir.join('fake-repo.log')
+    return tmp_path.joinpath('fake-repo.log')
 
 
 @pytest.mark.usefixtures('remove_fake_project_dir')
@@ -420,7 +487,10 @@ def test_debug_file_non_verbose(cli_runner, debug_file):
     assert not debug_file.exists()
 
     result = cli_runner(
-        '--no-input', '--debug-file', str(debug_file), 'tests/fake-repo-pre/',
+        '--no-input',
+        '--debug-file',
+        str(debug_file),
+        'tests/fake-repo-pre/',
     )
     assert result.exit_code == 0
 
@@ -430,7 +500,7 @@ def test_debug_file_non_verbose(cli_runner, debug_file):
         "DEBUG cookiecutter.main: context_file is "
         "tests/fake-repo-pre/cookiecutter.json"
     )
-    assert context_log in debug_file.readlines(cr=False)
+    assert context_log in debug_file.read_text()
     assert context_log not in result.output
 
 
@@ -457,17 +527,125 @@ def test_debug_file_verbose(cli_runner, debug_file):
         "DEBUG cookiecutter.main: context_file is "
         "tests/fake-repo-pre/cookiecutter.json"
     )
-    assert context_log in debug_file.readlines(cr=False)
+    assert context_log in debug_file.read_text()
     assert context_log in result.output
 
 
+@pytest.mark.usefixtures('make_fake_project_dir', 'remove_fake_project_dir')
+def test_debug_list_installed_templates(cli_runner, debug_file, user_config_path):
+    """Verify --list-installed command correct invocation."""
+    fake_template_dir = os.path.dirname(os.path.abspath('fake-project'))
+    os.makedirs(os.path.dirname(user_config_path))
+    with open(user_config_path, 'w') as config_file:
+        # In YAML, double quotes mean to use escape sequences.
+        # Single quotes mean we will have unescaped backslahes.
+        # http://blogs.perl.org/users/tinita/2018/03/
+        # strings-in-yaml---to-quote-or-not-to-quote.html
+        config_file.write("cookiecutters_dir: '%s'" % fake_template_dir)
+    open(os.path.join('fake-project', 'cookiecutter.json'), 'w').write('{}')
+
+    result = cli_runner(
+        '--list-installed',
+        '--config-file',
+        user_config_path,
+        str(debug_file),
+    )
+
+    assert "1 installed templates:" in result.output
+    assert result.exit_code == 0
+
+
+def test_debug_list_installed_templates_failure(
+    cli_runner, debug_file, user_config_path
+):
+    """Verify --list-installed command error on invocation."""
+    os.makedirs(os.path.dirname(user_config_path))
+    with open(user_config_path, 'w') as config_file:
+        config_file.write('cookiecutters_dir: "/notarealplace/"')
+
+    result = cli_runner(
+        '--list-installed', '--config-file', user_config_path, str(debug_file)
+    )
+
+    assert "Error: Cannot list installed templates." in result.output
+    assert result.exit_code == -1
+
+
 @pytest.mark.usefixtures('remove_fake_project_dir')
 def test_directory_repo(cli_runner):
     """Test cli invocation works with `directory` option."""
     result = cli_runner(
-        'tests/fake-repo-dir/', '--no-input', '-v', '--directory=my-dir',
+        'tests/fake-repo-dir/',
+        '--no-input',
+        '-v',
+        '--directory=my-dir',
     )
     assert result.exit_code == 0
-    assert os.path.isdir('fake-project')
-    with open(os.path.join('fake-project', 'README.rst')) as f:
-        assert 'Project name: **Fake Project**' in f.read()
+    assert os.path.isdir("fake-project")
+    with open(os.path.join("fake-project", "README.rst")) as f:
+        assert "Project name: **Fake Project**" in f.read()
+
+
+cli_accept_hook_arg_testdata = [
+    ("--accept-hooks=yes", None, True),
+    ("--accept-hooks=no", None, False),
+    ("--accept-hooks=ask", "yes", True),
+    ("--accept-hooks=ask", "no", False),
+]
+
+
+@pytest.mark.parametrize(
+    "accept_hooks_arg,user_input,expected", cli_accept_hook_arg_testdata
+)
+def test_cli_accept_hooks(
+    mocker,
+    cli_runner,
+    output_dir_flag,
+    output_dir,
+    accept_hooks_arg,
+    user_input,
+    expected,
+):
+    """Test cli invocation works with `accept-hooks` option."""
+    mock_cookiecutter = mocker.patch("cookiecutter.cli.cookiecutter")
+
+    template_path = "tests/fake-repo-pre/"
+    result = cli_runner(
+        template_path, output_dir_flag, output_dir, accept_hooks_arg, input=user_input
+    )
+
+    assert result.exit_code == 0
+    mock_cookiecutter.assert_called_once_with(
+        template_path,
+        None,
+        False,
+        replay=False,
+        overwrite_if_exists=False,
+        output_dir=output_dir,
+        config_file=None,
+        default_config=False,
+        extra_context=None,
+        password=None,
+        directory=None,
+        skip_if_file_exists=False,
+        accept_hooks=expected,
+    )
+
+
+@pytest.mark.usefixtures('remove_fake_project_dir')
+def test_cli_with_json_decoding_error(cli_runner):
+    """Test cli invocation with a malformed JSON file."""
+    template_path = 'tests/fake-repo-bad-json/'
+    result = cli_runner(template_path, '--no-input')
+    assert result.exit_code != 0
+
+    # Validate the error message.
+    # original message from json module should be included
+    pattern = 'Expecting \'{0,1}:\'{0,1} delimiter: line 1 column (19|20) \\(char 19\\)'
+    assert re.search(pattern, result.output)
+    # File name should be included too...for testing purposes, just test the
+    # last part of the file. If we wanted to test the absolute path, we'd have
+    # to do some additional work in the test which doesn't seem that needed at
+    # this point.
+    path = os.path.sep.join(['tests', 'fake-repo-bad-json', 'cookiecutter.json'])
+    assert path in result.output
