@@ -1,12 +1,9 @@
-# -*- coding: utf-8 -*-
-
 """Verify Jinja2 filters/extensions are available from pre-gen/post-gen hooks."""
-
-import io
 import os
 
 import freezegun
 import pytest
+import uuid
 
 from cookiecutter.main import cookiecutter
 
@@ -20,15 +17,15 @@ def freeze():
     freezer.stop()
 
 
-def test_jinja2_time_extension(tmpdir):
+def test_jinja2_time_extension(tmp_path):
     """Verify Jinja2 time extension work correctly."""
     project_dir = cookiecutter(
-        'tests/test-extensions/default/', no_input=True, output_dir=str(tmpdir)
+        'tests/test-extensions/default/', no_input=True, output_dir=str(tmp_path)
     )
     changelog_file = os.path.join(project_dir, 'HISTORY.rst')
     assert os.path.isfile(changelog_file)
 
-    with io.open(changelog_file, 'r', encoding='utf-8') as f:
+    with open(changelog_file, encoding='utf-8') as f:
         changelog_lines = f.readlines()
 
     expected_lines = [
@@ -36,17 +33,32 @@ def test_jinja2_time_extension(tmpdir):
         '-------\n',
         '\n',
         '0.1.0 (2015-12-09)\n',
-        '---------------------\n',
+        '------------------\n',
         '\n',
         'First release on PyPI.\n',
     ]
     assert expected_lines == changelog_lines
 
 
-def test_jinja2_slugify_extension(tmpdir):
+def test_jinja2_slugify_extension(tmp_path):
     """Verify Jinja2 slugify extension work correctly."""
     project_dir = cookiecutter(
-        'tests/test-extensions/default/', no_input=True, output_dir=str(tmpdir)
+        'tests/test-extensions/default/', no_input=True, output_dir=str(tmp_path)
     )
 
     assert os.path.basename(project_dir) == "it-s-slugified-foobar"
+
+
+def test_jinja2_uuid_extension(tmp_path):
+    """Verify Jinja2 uuid extension work correctly."""
+    project_dir = cookiecutter(
+        'tests/test-extensions/default/', no_input=True, output_dir=str(tmp_path)
+    )
+    changelog_file = os.path.join(project_dir, 'id')
+    assert os.path.isfile(changelog_file)
+
+    with open(changelog_file, encoding='utf-8') as f:
+        changelog_lines = f.readlines()
+
+    uuid.UUID(changelog_lines[0], version=4)
+    assert True
