@@ -1,9 +1,4 @@
-# -*- coding: utf-8 -*-
-
 """Verify generate context behaviour and context overwrite priorities."""
-
-from __future__ import unicode_literals
-
 import os
 import re
 from collections import OrderedDict
@@ -68,9 +63,7 @@ def test_generate_context_with_json_decoding_error():
     with pytest.raises(ContextDecodingException) as excinfo:
         generate.generate_context('tests/test-generate-context/invalid-syntax.json')
     # original message from json module should be included
-    pattern = (
-        'Expecting \'{0,1}:\'{0,1} delimiter: ' 'line 1 column (19|20) \\(char 19\\)'
-    )
+    pattern = 'Expecting \'{0,1}:\'{0,1} delimiter: line 1 column (19|20) \\(char 19\\)'
     assert re.search(pattern, str(excinfo.value))
     # File name should be included too...for testing purposes, just test the
     # last part of the file. If we wanted to test the absolute path, we'd have
@@ -115,6 +108,23 @@ def test_default_context_replacement_in_generate_context():
     assert generated_context == expected_context
 
 
+def test_generate_context_decodes_non_ascii_chars():
+    """Verify `generate_context` correctly decodes non-ascii chars."""
+    expected_context = {
+        'non_ascii': OrderedDict(
+            [
+                ('full_name', 'éèà'),
+            ]
+        )
+    }
+
+    generated_context = generate.generate_context(
+        context_file='tests/test-generate-context/non_ascii.json'
+    )
+
+    assert generated_context == expected_context
+
+
 @pytest.fixture
 def template_context():
     """Fixture. Populates template content for future tests."""
@@ -147,15 +157,42 @@ def test_apply_overwrites_sets_non_list_value(template_context):
     assert template_context['repo_name'] == 'foobar'
 
 
-def test_apply_overwrites_does_not_modify_choices_for_invalid_overwrite(
-    template_context,
-):
+def test_apply_overwrites_does_not_modify_choices_for_invalid_overwrite():
     """Verify variables overwrite for list if variable not in list ignored."""
-    generate.apply_overwrites_to_context(
-        context=template_context, overwrite_context={'orientation': 'foobar'}
+    expected_context = {
+        'choices_template': OrderedDict(
+            [
+                ('full_name', 'Raphael Pierzina'),
+                ('github_username', 'hackebrot'),
+                ('project_name', 'Kivy Project'),
+                ('repo_name', '{{cookiecutter.project_name|lower}}'),
+                ('orientation', ['all', 'landscape', 'portrait']),
+            ]
+        )
+    }
+
+    generated_context = generate.generate_context(
+        context_file='tests/test-generate-context/choices_template.json',
+        default_context={
+            'not_in_template': 'foobar',
+            'project_name': 'Kivy Project',
+            'orientation': 'foobar',
+        },
+        extra_context={
+            'also_not_in_template': 'foobar2',
+            'github_username': 'hackebrot',
+        },
     )
 
-    assert template_context['orientation'] == ['all', 'landscape', 'portrait']
+    assert generated_context == expected_context
+
+
+def test_apply_overwrites_invalid_overwrite(template_context):
+    """Verify variables overwrite for list if variable not in list not ignored."""
+    with pytest.raises(ValueError):
+        generate.apply_overwrites_to_context(
+            context=template_context, overwrite_context={'orientation': 'foobar'}
+        )
 
 
 def test_apply_overwrites_sets_default_for_choice_variable(template_context):
